summaryrefslogtreecommitdiff
path: root/src/mongo/db/pipeline/expression.h
diff options
context:
space:
mode:
authorDerick Rethans <github@derickrethans.nl>2017-07-04 14:44:15 +0100
committerDerick Rethans <github@derickrethans.nl>2017-07-12 11:46:23 +0100
commitc92d85fea435f64aedec07a2b42cbc16833ede82 (patch)
tree48138656fe46f2f299f7148d7c5a3bb148657a92 /src/mongo/db/pipeline/expression.h
parent99a0dfa12c700fe5ec4fd2170f17de37b24e9d55 (diff)
downloadmongo-c92d85fea435f64aedec07a2b42cbc16833ede82.tar.gz
SERVER-28610 Added timezone support (and %z and %Z) to $dateToString
Diffstat (limited to 'src/mongo/db/pipeline/expression.h')
-rw-r--r--src/mongo/db/pipeline/expression.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/src/mongo/db/pipeline/expression.h b/src/mongo/db/pipeline/expression.h
index aad2ced9b55..0a347bb6310 100644
--- a/src/mongo/db/pipeline/expression.h
+++ b/src/mongo/db/pipeline/expression.h
@@ -921,11 +921,13 @@ public:
private:
ExpressionDateToString(const boost::intrusive_ptr<ExpressionContext>& expCtx,
- const std::string& format, // the format string
- boost::intrusive_ptr<Expression> date); // the date to format
+ const std::string& format, // The format string.
+ boost::intrusive_ptr<Expression> date, // The date to format.
+ boost::intrusive_ptr<Expression> timeZone); // The optional timezone.
const std::string _format;
boost::intrusive_ptr<Expression> _date;
+ boost::intrusive_ptr<Expression> _timeZone;
};
class ExpressionDayOfMonth final : public DateExpressionAcceptingTimeZone<ExpressionDayOfMonth> {